package com.hai.service.impl;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.hai.common.security.UserCenter;
import com.hai.dao.ApiProductConfigMapper;
import com.hai.dao.ApiProductMapper;
import com.hai.entity.*;
import com.hai.model.UserInfoModel;
import com.hai.service.ApiProductService;
import com.hai.service.CommonService;
import org.apache.commons.collections4.MapUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.Map;

@Service("apiProductService")
public class ApiProductServiceImpl implements ApiProductService {

    @Resource
    private CommonService commonService;

    @Resource
    private ApiProductMapper apiProductMapper;

    @Resource
    private UserCenter userCenter;

    @Resource
    private ApiProductConfigMapper apiProductConfigMapper;

    @Override
    public void insertApiProduct(JSONObject object) {
        // 转换金额数组
        JSONArray priceArray = object.getJSONArray("prices");

        // api产品
        ApiProduct apiProduct;

        for (Object price : priceArray) {
            SecDictionary dictionary = commonService.mappingSysCode("RECHARGE_AMOUNT", String.valueOf(price));
            BigDecimal priceBd = new BigDecimal(dictionary.getCodeName());
            apiProduct = new ApiProduct();
            apiProduct.setRechargePrice(priceBd);
            apiProduct.setRechargeType(object.getInteger("rechargeType"));
            apiProduct.setPhoneRechargeType(object.getInteger("phoneRechargeType"));
            apiProduct.setOperatorType(object.getInteger("operatorType"));
            apiProduct.setRechargePlatform("-" + StringUtils.join(object.getJSONArray("rechargePlatform"), "-") + "-");
            apiProduct.setCreateTime(new Date());
            apiProduct.setUpdateTime(new Date());
            apiProduct.setStatus(102);
            apiProduct.setSort(1);
            apiProduct.setRechargeType(1);
            apiProduct.setOperatorName(object.getString("operatorName"));
            apiProduct.setOperatorId(object.getLong("operatorId"));
            apiProductMapper.insert(apiProduct);
        }

    }

    @Override
    public void updateApiProduct(ApiProduct apiProduct) {
        apiProductMapper.updateByPrimaryKeySelective(apiProduct);
    }

    @Override
    public List<ApiProduct> getListApiProduct(Map<String, Object> map) {
        ApiProductExample example = new ApiProductExample();
        ApiProductExample.Criteria criteria = example.createCriteria();


        if (MapUtils.getLong(map, "rechargePlatform") != null) {
            criteria.andRechargePlatformLike("%" + MapUtils.getLong(map, "rechargePlatform") + "%");
        }
        if (MapUtils.getLong(map, "rechargeType") != null) {
            criteria.andRechargeTypeEqualTo(MapUtils.getInteger(map, "rechargeType"));
        }
        if (MapUtils.getLong(map, "operatorType") != null) {
            criteria.andOperatorTypeEqualTo(MapUtils.getInteger(map, "operatorType"));
        }
        if (MapUtils.getLong(map, "phoneRechargeType") != null) {
            criteria.andPhoneRechargeTypeEqualTo(MapUtils.getInteger(map, "phoneRechargeType"));
        }
        if (MapUtils.getLong(map, "status") != null) {
            criteria.andStatusEqualTo(MapUtils.getInteger(map, "status"));
        } else {
            criteria.andStatusNotEqualTo(100);
        }

        example.setOrderByClause("sort asc");
        return apiProductMapper.selectByExample(example);
    }

    @Override
    public ApiProduct findById(Long id) {
        return apiProductMapper.selectByPrimaryKey(id);
    }

    @Override
    public void configApiProduct(JSONObject object) {

        // 操作人
        UserInfoModel sessionModel = userCenter.getSessionModel(UserInfoModel.class);

        // 转换产品数组
        JSONArray productsArray = object.getJSONArray("productIds");
        ApiProductConfig apiProductConfig;
        ApiProduct apiProduct;
        for (Object productId : productsArray) {
            apiProduct = apiProductMapper.selectByPrimaryKey(Long.valueOf(productId.toString()));
            apiProductConfig = new ApiProductConfig();
            apiProductConfig.setProductId(Long.valueOf(productId.toString()));
            apiProductConfig.setCreateTime(new Date());
            apiProductConfig.setOperatorId(sessionModel.getSecUser().getId());
            apiProductConfig.setOperatorName(sessionModel.getSecUser().getUserName());
            apiProductConfig.setStatus(101);
            apiProductConfig.setDiscount(object.getBigDecimal("discount"));
            apiProductConfig.setDiscountPrice(apiProduct.getRechargePrice().multiply(object.getBigDecimal("discount")).divide(new BigDecimal(100)));
            apiProductConfig.setMerchantsId(object.getLong("merchantsId"));
            apiProductConfig.setUpdateTime(new Date());
            apiProductConfigMapper.insert(apiProductConfig);
        }
    }

    @Override
    public ApiProductConfig findProductConfigById(Long id) {
        return apiProductConfigMapper.selectByPrimaryKey(id);
    }

    @Override
    public void updateConfigApiProduct(ApiProductConfig apiProductConfig) {
        apiProductConfigMapper.updateByPrimaryKey(apiProductConfig);
    }

    @Override
    public ApiProductConfig findMchProduct(Map<String, Object> map) {
        ApiProductConfigExample example = new ApiProductConfigExample();
        ApiProductConfigExample.Criteria criteria = example.createCriteria();

        if (MapUtils.getLong(map , "merchantsId") != null) {
            criteria.andMerchantsIdEqualTo(MapUtils.getLong(map , "merchantsId"));
        }
        if (MapUtils.getLong(map , "productId") != null) {
            criteria.andProductIdEqualTo(MapUtils.getLong(map , "productId"));
        }

        List<ApiProductConfig> list = apiProductConfigMapper.selectByExample(example);

        if (list.size() > 0) {
            return list.get(0);
        } else {
            return null;
        }

    }
}
